.. _bluegraph_core_embed_ref:

`bluegraph.core.embed` package
------------------------------

Reference page for the `bluegraph.core.embed` package.


Graph embedding
^^^^^^^^^^^^^^^

.. automodule:: bluegraph.core.embed.embedders
	:members:
